/* -*- Mode: C; c-basic-offset:4 ; -*- */
/* 
 *   $Id: ad_piofs.h,v 1.3 2003/03/25 22:40:09 nsanghvi Exp $    
 *
 *   Copyright (C) 1997 University of Chicago. 
 *   See COPYRIGHT notice in top-level directory.
 */

/* contains definitions, declarations, and macros specific to the
   implementation of ADIO on PIOFS */

#ifndef AD_PIOFS_INCLUDE
#define AD_PIOFS_INCLUDE

#include <unistd.h>
#include <sys/uio.h>
#include <sys/types.h>
#include <fcntl.h>
#include <piofs/piofs_ioctl.h>
#include "adio.h"

#endif
